==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebRowSelectionEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebRowSelectionEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowSelectionEventArgsDetailDescription, _super);
    function WebRowSelectionEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.s = null;
        _this.r = null;
        _this.q = null;
        _this.t = null;
        _this.n = false;
        return _this;
    }
    WebRowSelectionEventArgsDetailDescription.prototype.get_type = function () {
        return "WebRowSelectionEventArgsDetail";
    };
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "oldSelectionRef", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.g("OldSelectionRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "newSelectionRef", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.g("NewSelectionRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "addedRef", {
        get: function () {
            return this.q;
        },
        set: function (a) {
            this.q = a;
            this.g("AddedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "removedRef", {
        get: function () {
            return this.t;
        },
        set: function (a) {
            this.t = a;
            this.g("RemovedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "allRowsSelected", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.g("AllRowsSelected");
        },
        enumerable: false,
        configurable: true
    });
    WebRowSelectionEventArgsDetailDescription.$t = markType(WebRowSelectionEventArgsDetailDescription, 'WebRowSelectionEventArgsDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebRowSelectionEventArgsDetailDescription.__marshalByValue1 = true;
    WebRowSelectionEventArgsDetailDescription.__marshalByValueAlias1 = "RowSelectionEventArgsDetail";
    return WebRowSelectionEventArgsDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebRowSelectionEventArgsDetailDescription };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebRowSelectionEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebRowSelectionEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowSelectionEventArgsDetailDescription, _super);
    function WebRowSelectionEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.r = null;
        _this.q = null;
        _this.p = null;
        _this.s = null;
        _this.i = false;
        _this.j = false;
        _this.m = null;
        return _this;
    }
    WebRowSelectionEventArgsDetailDescription.prototype.get_type = function () {
        return "WebRowSelectionEventArgsDetail";
    };
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "oldSelectionRef", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.g("OldSelectionRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "newSelectionRef", {
        get: function () {
            return this.q;
        },
        set: function (a) {
            this.q = a;
            this.g("NewSelectionRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "addedRef", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.g("AddedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "removedRef", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.g("RemovedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "allRowsSelected", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("AllRowsSelected");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "cancel", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("Cancel");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRowSelectionEventArgsDetailDescription.prototype, "owner", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.g("Owner");
        },
        enumerable: false,
        configurable: true
    });
    WebRowSelectionEventArgsDetailDescription.$t = markType(WebRowSelectionEventArgsDetailDescription, 'WebRowSelectionEventArgsDetailDescription', Description.$);
    WebRowSelectionEventArgsDetailDescription.__marshalByValue = true;
    WebRowSelectionEventArgsDetailDescription.__marshalByValueAlias = "RowSelectionEventArgsDetail";
    return WebRowSelectionEventArgsDetailDescription;
}(Description));
export { WebRowSelectionEventArgsDetailDescription };
